import { Parser } from '../../infrastructure/parser';
export class XmlViewerComponent {
    componentDidLoad() {
        console.log('The component has been rendered');
    }
    prepareXml() {
        let xdoc = Parser.Parse(this.xml.trim());
        return xdoc;
    }
    renderAttribute(attribute) {
        return (h("span", null,
            "\u00A0",
            h("span", { class: "attr" }, attribute.name),
            h("span", null,
                "=\"",
                attribute.value,
                "\"")));
    }
    renderNodeValue(nodeValue) {
        if (!nodeValue) {
            return null;
        }
        if (nodeValue.length > 150) {
            return (h("ul", null,
                h("li", null, nodeValue)));
        }
        else {
            return (h("span", null, nodeValue));
        }
    }
    // Rest operator transpiles into sequence.slice() - but sequence is not an array. So I made it by myself
    // toArray(nodes){
    //   var arr = [];
    //   for(let i=0;i<nodes.length;i++){
    //     arr.push(nodes[i]);
    //   }
    //   return arr;
    // }
    // rendering node. This function calls to itself in recursion way in case of child nodes
    renderNode(node) {
        if (!node) {
            return null;
        }
        // let children = this.toArray(node.children);//[...node.children];
        // let attributes = this.toArray(node.attributes);//[...node.attributes];
        let children = [...node.children];
        let attributes = [...node.attributes];
        let nodeValue = node.firstChild ? node.firstChild.nodeValue : null;
        nodeValue = nodeValue ? nodeValue.trim() : null;
        return (h("ul", null,
            h("li", null,
                h("span", { class: "element" }, "<"),
                h("span", { class: "element" }, node.nodeName),
                attributes.map((a) => this.renderAttribute(a)),
                h("span", { class: "element" }, ">"),
                this.renderNodeValue(nodeValue),
                children.map((c) => this.renderNode(c)),
                h("span", { class: "element" }, "</"),
                h("span", { class: "element" }, node.nodeName),
                h("span", { class: "element" }, ">"))));
    }
    render() {
        console.log('rendered');
        if (this.xml === null || this.xml === undefined) {
            return null;
        }
        if (this.xml.length === 0) {
            return null;
        }
        let xdoc = null;
        try {
            xdoc = this.prepareXml();
        }
        catch (e) {
        }
        if (!xdoc || !xdoc.documentElement.childNodes) {
            return (h("code", null, this.xml));
        }
        return (h("p", null,
            h("code", null, this.renderNode(xdoc.documentElement))));
    }
    static get is() { return "xml-viewer-component"; }
    static get encapsulation() { return "shadow"; }
    static get properties() { return { "xml": { "type": String, "attr": "xml" } }; }
    static get style() { return "/**style-placeholder:xml-viewer-component:**/"; }
}
//# sourceMappingURL=xml-viewer-component.js.map